@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 sub new {
     my $class = shift;
@@ -103,8 +103,15 @@ sub _parent {
             chomp($line);
 
             if ( not $session->{established} ) {
-                if ( $line =~ /^(ERROR)\s/ ) {
-                    die $line . "\n";
+                if ( $line =~ /^ERROR.+onnect\w+ too fast/ ) {
+                    warn "$line\n";
+                    warn "Sleeping 20 and retrying...\n";
+                    sleep 20;
+                    $device->daemon->do_restart;
+                }
+                elsif ( $line =~ /^ERROR\s/ ) {
+                    warn "$line\n";
+                    $device->daemon->do_stop;
                 }
                 elsif ( not $session->{user} ) {
                     $self->say("USER $self->{nick} 0 * :$self->{connect}{name}");
@@ -206,7 +213,18 @@ sub _on_message {
             }
         }
 
-        hook: for my $hook ( @{ $self->{hooks} } ) {
+        hook: for my $hook (
+            @{ $self->{hooks} },
+            {
+                when => {
+                    to_me => 1,
+                },
+                code => sub {
+                    my ( $bot, $in ) = @_;
+                    $bot->reply_to(qq{Sorry. I don't understand. (Try "$bot->{nick} help" for help.)});
+                },
+            },
+        ) {
             my $captured_matches = {};
 
             for my $type ( keys %{ $hook->{when} } ) {
@@ -460,7 +478,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
